# =========================================================================== #
# Gemspec for Project Extracter.
# =========================================================================== #
require 'extracter/version/version.rb'
begin
#  require 'roebe'
require 'roebe/toplevel_methods/misc.rb'
rescue LoadError; end

Gem::Specification.new { |s|

  s.name    = 'extracter'
  s.version = Extracter::VERSION
  s.date    = Time.now.strftime('%Y-%m-%d')

  DESCRIPTION = <<-EOF

This fairly small gem can be used to extract different
archive formats, such as .tar.bz2, .tar.gz, .tbz,
.zip, .gem, .lzma and various more.

Audio can be extracted as well, via ffmpeg, if the gem called
multimedia_paradise is installed.

This project, however had, depends on external tools,
such as tar (on Linux) or 7z / 7zip (on Windows), so
these have to be installed first.

For more information about this project have a look
at the homepage, at
https://rubygems.org/gems/extracter.

EOF

  s.summary     = DESCRIPTION
  s.description = DESCRIPTION

  s.authors  = ['Robert A. Heiler']
  s.email    = Roebe.email?
  s.files    = Dir['**/*']
  s.licenses = 'MIT'
  s.homepage = 'https://rubygems.org/gems/extracter'

  # ========================================================================= #
  # Show this when a user installs the project.
  # ========================================================================= #
  s.post_install_message = <<-EOF

  class Extracter can be used to extract archives, such as .tar.gz or
  .zip.

  If you need some help, you can invoke bin/extract via:

      extract --help

  In general, the syntax for extract is kept simple. Just pass in the
  archive that has to be extracted as the first argument to 
  extract ( bin/extract) , and class Extracter will try to extract
  it, if it is a registered archive format.

  In ruby code, you may be able to use class Extracter in this manner:

      require 'extracter'
      Extracter[file_path_here]

  or

      require 'extracter'
      Extracter.new(file_path_here)

  Specific example:

      require 'extracter'
      Extracter.new('htop-2.2.0.tar.xz')

  See the --help option.

  EOF

  s.required_ruby_version     = '>= '+'3.2.2' # Roebe.third_most_stable_version_of_ruby
  s.required_rubygems_version = '>= '+Gem::VERSION
  s.rubygems_version          = '>= '+Gem::VERSION

  # ========================================================================= #
  # Specify the dependencies for this gem:
  # ========================================================================= #
  s.add_dependency 'opn'

}
